@@ -36,7 +36,8 @@ def cloud_spi():
             func = app.view_functions[rule.endpoint]
             # 调用业务方法
             result = func()
-            app.logger.info("Spi handler response : %s", result)
+            app.logger.info("Spi handler response : %s",
+                            json.dumps(result, default=lambda obj: obj.__dict__, ensure_ascii=False))
             # 检查不合法返回值
             if 'code' not in result or 'success' not in result:
                 app.logger.error("Spi handler response is invalid! Please use #success_result or #failed_result!")
